<?php
/**
 * Content File Logic
 * @package     Content
 * @copyright   Copyright (C) 2012 MicroEngine Inc.
 */
class Content_File_Logic
{
    /** 画像一覧のアイテム数 */
    const PAGINATOR_SIZE = 20;

    /**
     * DAOオブジェクト
     * @var Content_File_Dao
     */
    private $dao;

    /**
     * コンストラクタ
     */
    public function __construct()
    {
        $this->dao = new Content_File_Dao();
    }

    /**
     * ファイル登録処理
     * @param string $file_path
     * @param integer $page_id
     * @param string $page_path
     * @param integer $user_id
     * @param string $user_name
     * @return Content_File $content_file
     */
    public function register($file_path, $page_id, $page_path, $user_id, $user_name)
    {
        $content_file = new Content_File(basename($file_path), $file_path, $page_id, $page_path, $user_id, $user_name);
        $this->dao->insert($content_file);
        return $content_file;
    }

    /**
     * ファイル一覧取得
     * @param string $path
     * @param string $position
     * @return array $rows, integer $total
     */
    public function get_file_list($path, $position)
    {
        $rows = $this->dao->get_file_list($path, self::PAGINATOR_SIZE + 1, $position * self::PAGINATOR_SIZE);
        $total = $this->dao->get_file_list_count($path);
        return array($rows, $total);
    }

    /**
     * ファイル情報取得
     * @param string $file_id
     * @return Content_File $file
     */
    public function get_file($file_id)
    {
        $file = $this->dao->select($file_id);

        return $file;
    }

    /**
     * ファイル削除
     * @param Content_File $file
     * @return boolean 
     */
    public function delete_file(Content_File $file)
    {
        // DBからレコードを削除する
        $this->dao->delete($file);

        // ファイルを削除する
        $file_path = DOCUMENT_ROOT . $file->file_path;
        if (file_exists($file_path)) {
            unlink($file_path);
        }

        return true;
    }
}