<?php
/**
 * Page Dao
 * @package     Page
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Page_Dao extends Me_Dao
{
    /**
     * テーブル名
     * @var string
     */
    public $table_name = 'page';
    /**
     * Entityクラス名
     * @var stirng
     */
    public $class_name = 'Page';
    /**
     * カラム定義配列
     * @var array
     */
    public $column_list = array(
        '_id',
        'template_id',
        'page_path',
        'page_type',
        'directory',
        'file_name',
        'extension',
        'char_code',
        'public_flag',
        'title',
        'keywords',
        'description',
        'note',
        'user_id',
        'user_name',
        'create_date',
        'update_date',
    );

    /**
     * コンストラクタ
     */
    public function __construct()
    {

    }

    /**
     * 登録済みページリスト
     * @return array $rows
     */
    public function select_registered_list()
    {
        $query = <<< QUERY
select _id, page_path, page_type from page
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * ページリスト取得
     * @param string $dir
     * @return array $rows
     */
    public function select_page_list($dir = '')
    {
        if ($dir === null) {
            $dir = '';
        }
        $order = ($order === 'update_date') ? 'update_date' : 'file_name';
        $sort = ($sort === 'desc') ? 'desc' : 'asc';

        $query = <<< QUERY
select p._id, p.page_path, p.page_type, p.directory, p.file_name, p.extension, p.note, p.update_date, t.template_type from page as p
left outer join template as t on (p.template_id = t._id)
where directory = ''
order by page_type asc , file_name asc
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $dir);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * ファイル名リスト取得
     * @param string $dir
     * @return array $rows
     */
    public function select_file_name_list($dir = '')
    {
        if ($dir === null) {
            $dir = '';
        }

        $query = <<< QUERY
select file_name from page
where directory = ''
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $dir);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * ページリスト取得
     * @param string $template_id
     * @return array $rows
     */
    public function select_page_list_by_template_id($template_id)
    {
        if ($template_id === null || $template_id === '') {
            throw new Me_Exception(600);
        }

        $query = <<< QUERY
select p._id, p.page_path, p.page_type, p.directory, p.file_name, p.update_date from page as p
where p.template_id = 1
order by p._id desc
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $template_id);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * ページID取得
     * @param string $template_id
     * @return array $rows
     */
    public function select_page_id_by_template_id($template_id)
    {
        if ($template_id === null || $template_id === '') {
            throw new Me_Exception(600);
        }

        $query = <<< QUERY
select p._id from page as p
where p.template_id = 1
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $template_id);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * リンク選択用データ取得
     * @param string $dir
     * @return array $rows
     */
    public function select_link_by_dir($dir)
    {
        if ($dir === null) {
            $dir = '/';
        }

        $query = <<< QUERY
select p._id, p.page_path, p.page_type, p.file_name, p.extension, p.note, t.template_type
from page as p
left outer join template as t on (p.template_id = t._id)
where p.directory = ''
order by page_type asc , file_name asc
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $dir);
        $rows = $sql->exec();
        return $rows;
    }

    /**
     * ページ情報取得
     * @param string $page_path
     * @return array $row
     */
    public function select_by_page_path($page_path = '')
    {
        $row = null;
        $query = <<< QUERY
select p._id, template_id, page_type, p.page_path, p.note, t.template_type, d._id as draft_id
from page as p
left outer join template as t on (p.template_id = t._id)
left outer join page_draft as d on (p._id = d.page_id)
where p.page_path = '' and p.page_type != '1'
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page_path);
        $rows = $sql->exec();

        if (count($rows) === 1) {
            $row = $rows[0];
        }
        return $row;
    }

    /**
     * ページ情報取得
     * @param string $page_path
     * @return array $row
     */
    public function select_page_info($page_path = '')
    {
        $row = array();
        $query = <<< QUERY
select p._id, p.page_path, p.user_name, p.note, p.update_date,
 d._id as draft_id, d.user_name as draft_user_name, d.note as draft_note, d.comment as draft_comment, d.create_date as draft_create_date,
 r.comment as revision_comment
from page as p
left outer join page_draft as d on (p._id = d.page_id)
left outer join page_revision as r on (p._id = r.page_id)
where p.page_path = '' and p.page_type == '2'
order by r.create_date desc limit 1
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page_path);
        $rows = $sql->exec();

        if (count($rows) === 1) {
            $row = $rows[0];
        }
        if (strlen($row['user_name']) < 1) {
            $row['update_date'] = '';
        }
        return $row;
    }

    /**
     * ページID取得
     * @param string $page_path
     * @return string $page_id
     */
    public function select_id_by_page_path($page_path = '')
    {
        $page_id = null;
        $query = <<< QUERY
select _id
from page
where page_path = ''
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page_path);
        $rows = $sql->exec();

        if (count($rows) === 1) {
            $page_id = $rows[0]['_id'];
        }
        return $page_id;
    }

    /**
     * page_type更新
     * @param string $template_id
     * @return boolean
     */
    public function update_page_type($template_id)
    {
        if ($template_id === null) {
            return false;
        }

        $query = <<< QUERY
update page set page_type = '3' , template_id = null
where template_id = 2
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->replace('update', 5, Page_Logic::PAGE_TYPE_FILE);
        $sql->bind('where', 3, $template_id);
        $sql->exec();
        return true;
    }

    /**
     * 非公開ページ削除
     * @param string $template_id
     * @return boolean
     */
    public function delete_not_public($template_id)
    {
        if ($template_id === null) {
            return false;
        }

        $query = <<< QUERY
delete from page
where template_id = 2 and public_flag = 0
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $template_id);
        $sql->exec();
        return true;
    }

    /**
     * ページ情報セット
     * @param Page_Output $page
     * @return boolean
     */
    public function set_page(Page_Output $page)
    {
        $row = null;
        $query = <<< QUERY
select template_id, page_type, page_path, public_flag, title, keywords, description, create_date, update_date
from page
where _id = 0
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page->_id);
        $rows = $sql->exec();

        if (count($rows) === 1) {
            $row = $rows[0];
            $page->template_id = $row['template_id'];
            $page->page_type = $row['page_type'];
            $page->page_path = $row['page_path'];
            $page->public_flag = $row['public_flag'];
            $page->title = $row['title'];
            $page->keywords = $row['keywords'];
            $page->description = $row['description'];
            $page->create_date = $row['create_date'];
            $page->update_date = $row['update_date'];
            return true;
        } else {
            return false;
        }
    }

    /**
     * 更新ページ一覧取得（ユーザー限定）
     * @param integer $user_id
     * @return array $rows
     */
    public function select_updated_list($user_id)
    {
        $query = <<< QUERY
select _id, page_path, user_name, update_date
from page
where user_id = 1
order by update_date desc limit 10
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $user_id);
        $rows = $sql->exec();
        return $rows;
    }
    
    /**
     * 更新ページ一覧取得（全て）
     * @return array $rows
     */
    public function select_updated_all_list()
    {
        $query = <<< QUERY
select _id, page_path, user_name, update_date
from page
where user_id is not null
order by update_date desc limit 10
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $rows = $sql->exec();
        return $rows;        
    }
}